==> currency_cloud-1.0.0.tar.gz: tool/grind.dart <==
library currency_cloud_dart.tool.grind;

import 'dart:io' hide ProcessException;
import 'dart:mirrors';

import 'package:grinder/grinder.dart';
import 'package:logging/logging.dart';

final Directory projectRoot =
    new Directory.fromUri(currentMirrorSystem().findLibrary(#currency_cloud_dart.tool.grind).uri)
        .parent
        .parent
        .absolute;

final int dartFmtLineLenght = 120;

main(List<String> args) {
  Logger.root.onRecord.listen((record) => log(record.message));
  grind(args);
}

@Task('Runs dartanalyzer and ignores problems listed in the exclude section of analysis_options.yaml')
analyze() async {
  final executable = 'dartanalyzer', arguments = ['--fatal-infos', '--fatal-warnings', '.'];
  log('$executable ${arguments.join(' ')}');
  final result = Process.runSync(executable, arguments, workingDirectory: projectRoot.path);

  if (result.exitCode != 0) {
    log(result.stdout.toString());
    fail('Analyzer discovered problems');
  } else {
    log('All good!');
  }
}

@Task()
checkFormat() {
  if (DartFmt.dryRun(projectRoot, lineLength: dartFmtLineLenght))
    fail('Code is not properly formatted. Run `grind format`');
}

@Task()
clean() => defaultClean();

@Task()
format() => DartFmt.format(projectRoot, lineLength: dartFmtLineLenght);

/// returns true if the executable is available
bool isAvailableExecutable(String executable) {
  var runOptions = new RunOptions(environment: Platform.environment, runInShell: true);
  try {
    run('hash', arguments: [executable, '2>/dev/null'], runOptions: runOptions);
    return true;
  } catch (_) {
    return false;
  }
}

@Task()
@Depends(checkFormat, analyze, testUnit)
test() => true;

@Task()
testUnit() => new TestRunner().testAsync(files: new Directory('test'), concurrency: 4);

==> currency_cloud-1.0.2.tar.gz: tool/grind.dart <==
library currency_cloud_dart.tool.grind;

import 'dart:io' hide ProcessException;
import 'dart:mirrors';

import 'package:grinder/grinder.dart';
import 'package:logging/logging.dart';

final Directory projectRoot = new Directory.fromUri(
        currentMirrorSystem().findLibrary(#currency_cloud_dart.tool.grind).uri)
    .parent
    .parent
    .absolute;

final int dartFmtLineLenght = 80;

main(List<String> args) {
  Logger.root.onRecord.listen((record) => log(record.message));
  grind(args);
}

@Task(
    'Runs dartanalyzer and ignores problems listed in the exclude section of analysis_options.yaml')
analyze() async {
  final executable = 'dartanalyzer',
      arguments = ['--fatal-infos', '--fatal-warnings', '.'];
  log('$executable ${arguments.join(' ')}');
  final result = Process.runSync(executable, arguments,
      workingDirectory: projectRoot.path);

  if (result.exitCode != 0) {
    log(result.stdout.toString());
    fail('Analyzer discovered problems');
  } else {
    log('All good!');
  }
}

@Task()
checkFormat() {
  if (DartFmt.dryRun(projectRoot, lineLength: dartFmtLineLenght))
    fail('Code is not properly formatted. Run `grind format`');
}

@Task()
clean() => defaultClean();

@Task()
format() => DartFmt.format(projectRoot, lineLength: dartFmtLineLenght);

/// returns true if the executable is available
bool isAvailableExecutable(String executable) {
  var runOptions =
      new RunOptions(environment: Platform.environment, runInShell: true);
  try {
    run('hash', arguments: [executable, '2>/dev/null'], runOptions: runOptions);
    return true;
  } catch (_) {
    return false;
  }
}

@Task()
@Depends(checkFormat, analyze, testUnit)
test() => true;

@Task()
testUnit() =>
    new TestRunner().testAsync(files: new Directory('test'), concurrency: 4);
